@@ -24,7 +24,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-__all__ = ['Client']
+__all__ = [
+	'Client',
+	'utils'
+]
 
 __title__ = 'opentdb-py'
 __author__ = 'Marseel Eeso'
@@ -81,10 +84,10 @@ class Client:
 				return data['token']
 
 	async def reset_session_token(self) -> None:
-		self.token = await self._request(endpoint="api_token.php", command="reset")
+		self.session_token = await self._request(endpoint="api_token.php", command="reset")
 
 	async def _request(self, endpoint: str, **params) -> Union[CategoriesList, CategoryQuestionsCount, GlobalQuestionsCount, QuestionResponse]:
-		params['token'] = self.token
+		params['token'] = self.session_token
 
 		if self.session is None:
 			self.session = aiohttp.ClientSession()
